%define uname   SCons

Name:           scons
Epoch:          1
Version:        4.8.0
Release:        %mkrel 1
Summary:        Open Source software construction tool
License:        MIT
Group:          Development/Other
URL:            https://www.scons.org
Source0:        https://download.sourceforge.net/scons/%{uname}-%{version}.tar.gz
Source1:        scons.macros
Patch0:         scons-fix-manpage-dir.patch

BuildArch:      noarch
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)

Provides:       python3-scons = %{epoch}:%{version}-%{release}

%description
SCons is an Open Source software construction tool--that is, a build
tool; an improved substitute for the classic Make utility; a better way
to build software. SCons is based on the design which won the Software
Carpentry build tool design competition in August 2000.

SCons "configuration files" are Python scripts, eliminating the need
to learn a new build tool syntax. SCons maintains a global view of
all dependencies in a tree, and can scan source (or other) files for
implicit dependencies, such as files specified on #include lines. SCons
uses MD5 signatures to rebuild only when the contents of a file have
really changed, not just when the timestamp has been touched. SCons
supports side-by-side variant builds, and is easily extended with user-
defined Builder and/or Scanner objects.

%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires -x tests

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files SCons

# Kept for compatibility with scripts which might expect `scons-3`.
# The other aliases were removed as not really useful now that we don't have py2 variants.
ln -fs %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}-3

# install scons rpm macro helper
install -D -p -m 0644 %{_sourcedir}/%{name}.macros \
  %{buildroot}%{_rpmmacrodir}/macros.%{name}

%files -f %{pyproject_files}
%doc README.rst
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}-3
%{_bindir}/%{name}-configure-cache
%{_bindir}/%{name}ign
%{_mandir}/man1/%{name}*.1*
%{_rpmmacrodir}/macros.%{name}


%changelog
* Thu Jul 11 2024 daviddavid <daviddavid> 1:4.8.0-1.mga10
+ Revision: 2080641
- new version: 4.8.0

* Thu Mar 21 2024 daviddavid <daviddavid> 1:4.7.0-1.mga10
+ Revision: 2051153
- new version: 4.7.0

* Tue Dec 19 2023 daviddavid <daviddavid> 1:4.6.0-2.mga10
+ Revision: 2019234
- rebuild for py3.12

* Sun Dec 03 2023 daviddavid <daviddavid> 1:4.6.0-1.mga10
+ Revision: 2012790
- new version: 4.6.0
- switch to pyproject

* Mon Aug 28 2023 daviddavid <daviddavid> 1:4.5.2-1.mga10
+ Revision: 1980561
- new version: 4.5.2

* Mon Aug 22 2022 papoteur <papoteur> 1:4.4.0-1.mga9
+ Revision: 1879157
- new 4.4.0

* Wed Mar 23 2022 umeabot <umeabot> 1:4.3.0-3.mga9
+ Revision: 1822624
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tv <tv> 1:4.3.0-2.mga9
+ Revision: 1774601
- Rebuild for python-3.10

* Sun Jan 23 2022 wally <wally> 1:4.3.0-1.mga9
+ Revision: 1769483
- new version 4.3.0

* Sun Oct 10 2021 wally <wally> 1:4.2.0-1.mga9
+ Revision: 1750528
- new version 4.2.0
- move rpm macros to %%_rpmmacrodir

* Sat Mar 20 2021 daviddavid <daviddavid> 1:4.1.0-2.mga9
+ Revision: 1705242
- rebuild for python 3.9

* Fri Feb 26 2021 daviddavid <daviddavid> 1:4.1.0-1.mga9
+ Revision: 1692221
- new version: 4.1.0

* Fri Oct 23 2020 akien <akien> 1:4.0.1-1.mga8
+ Revision: 1638828
- Version 4.0.1.
- Simplify packaging by merging 'python3-scons' into the main package,
  since we no longer need to provide a python2 variant.
- Drop most '*-3' aliases, but keep 'scons-3' for compatibility with
  scripts written for older Fedora/RHEL.

* Thu Feb 20 2020 umeabot <umeabot> 1:3.1.2-3.mga8
+ Revision: 1546119
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 1:3.1.2-2.mga8
+ Revision: 1486035
- update scons rpm macros
+ wally <wally>
- remove kde3 scons rpm macros

* Tue Dec 17 2019 daviddavid <daviddavid> 1:3.1.2-1.mga8
+ Revision: 1468613
- new version: 3.1.2

* Fri Sep 13 2019 tv <tv> 1:3.1.1-2.mga8
+ Revision: 1440263
- rebuild for python-3.8
- drop python2 subpkg

* Mon Aug 19 2019 daviddavid <daviddavid> 1:3.1.1-1.mga8
+ Revision: 1429927
- new version: 3.1.1

* Sun Jul 21 2019 daviddavid <daviddavid> 1:3.1.0-1.mga8
+ Revision: 1423382
- new version: 3.1.0

* Fri Apr 05 2019 daviddavid <daviddavid> 1:3.0.5-2.mga7
+ Revision: 1385966
- add scons macros for Python 2 support
- improve some descriptions and summaries

* Thu Mar 28 2019 daviddavid <daviddavid> 1:3.0.5-1.mga7
+ Revision: 1380720
- new version: 3.0.5
- main scons pkg require now python3-scons

* Tue Mar 26 2019 akien <akien> 1:3.0.4-2.mga7
+ Revision: 1380374
- Switch scons package to py3 by default

* Wed Jan 23 2019 daviddavid <daviddavid> 1:3.0.4-1.mga7
+ Revision: 1359908
- new version: 3.0.4

* Tue Jan 08 2019 daviddavid <daviddavid> 1:3.0.3-1.mga7
+ Revision: 1352347
- new version: 3.0.3

* Mon Jan 07 2019 daviddavid <daviddavid> 1:3.0.2-1.mga7
+ Revision: 1350684
- new version: 3.0.2
- rebuild for new python 3.7

* Fri Sep 21 2018 umeabot <umeabot> 1:3.0.1-3.mga7
+ Revision: 1291472
- Mageia 7 Mass Rebuild

* Thu Jul 19 2018 joequant <joequant> 1:3.0.1-2.mga7
+ Revision: 1244299
- install python3 version of scons

* Fri Nov 24 2017 daviddavid <daviddavid> 1:3.0.1-1.mga7
+ Revision: 1179076
- new version: 3.0.1

* Sat Sep 23 2017 daviddavid <daviddavid> 1:3.0.0-1.mga7
+ Revision: 1157850
- new version: 3.0.0
- fix manpages install path

* Fri Sep 15 2017 daviddavid <daviddavid> 1:2.5.1-2.mga7
+ Revision: 1154416
- rename python-scons to python2-scons
+ tv <tv>
- fix SRPM creation due to bad %%py2_install call

* Fri Nov 11 2016 akien <akien> 1:2.5.1-1.mga6
+ Revision: 1066446
- Version 2.5.1

* Thu Apr 14 2016 daviddavid <daviddavid> 1:2.5.0-1.mga6
+ Revision: 1001524
- new version: 2.5.0
- use new python macros
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Nov 12 2015 daviddavid <daviddavid> 1:2.4.1-1.mga6
+ Revision: 902725
- new version: 2.4.1

* Tue Sep 22 2015 daviddavid <daviddavid> 1:2.4.0-1.mga6
+ Revision: 882185
- new version: 2.4.0
- use new python2 macros
- introduce license macro

* Sat Aug 01 2015 daviddavid <daviddavid> 1:2.3.6-1.mga6
+ Revision: 860232
- new version: 2.3.6

* Fri Jul 24 2015 daviddavid <daviddavid> 1:2.3.5-1.mga6
+ Revision: 856765
- new version: 2.3.5

* Sat Jun 20 2015 daviddavid <daviddavid> 1:2.3.4-1.mga6
+ Revision: 835788
- new version: 2.3.4

* Wed Oct 15 2014 umeabot <umeabot> 1:2.3.3-4.mga5
+ Revision: 740348
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:2.3.3-3.mga5
+ Revision: 730116
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:2.3.3-2.mga5
+ Revision: 689073
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 daviddavid <daviddavid> 1:2.3.3-1.mga5
+ Revision: 669644
- new version: 2.3.3
- update Source0 link-url

* Sat Jun 28 2014 pterjan <pterjan> 1:2.3.1-1.mga5
+ Revision: 640773
- 2.3.1
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1:2.3.0-3.mga4
+ Revision: 544543
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1:2.3.0-2.mga4
+ Revision: 499851
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Oct 14 2013 oden <oden> 1:2.3.0-1.mga4
+ Revision: 496851
- 2.3.0

* Mon Jan 14 2013 umeabot <umeabot> 1:2.2.0-2.mga3
+ Revision: 381890
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 fwang <fwang> 1:2.2.0-1.mga3
+ Revision: 292516
- new version 2.2.0

* Thu Jan 05 2012 fwang <fwang> 1:2.1.0-1.mga2
+ Revision: 191115
- new version 2.1.0

* Tue Jan 18 2011 pterjan <pterjan> 1:2.0.1-3.mga1
+ Revision: 21807
- Rebuild for python 2.7
+ dmorgan <dmorgan>
- imported package scons


* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 1:2.0.1-2mdv2011.0
+ Revision: 590140
- rebuild for python 2.7

* Sun Aug 29 2010 Emmanuel Andry <eandry@mandriva.org> 1:2.0.1-1mdv2011.0
+ Revision: 574167
- New version 2.0.1

* Mon Apr 05 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:1.3.0-1mdv2010.1
+ Revision: 531572
- update to new version 1.3.0
- disable patch 0

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1:1.2.0-3mdv2010.1
+ Revision: 524072
- rebuilt for 2010.1

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 1:1.2.0-2mdv2010.0
+ Revision: 427063
- rebuild

* Sun Dec 28 2008 Adam Williamson <awilliamson@mandriva.org> 1:1.2.0-1mdv2009.1
+ Revision: 320094
- new release 1.2.0 (maybe this will fix my weird-ass build error in beid)

* Wed Dec 24 2008 Michael Scherer <misc@mandriva.org> 1:1.1.0-2mdv2009.1
+ Revision: 318437
- rebuild for new python

* Tue Oct 21 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:1.1.0-1mdv2009.1
+ Revision: 296192
- update to new version 1.1.0

* Thu Sep 11 2008 Frederik Himpe <fhimpe@mandriva.org> 1:1.0.1-1mdv2009.0
+ Revision: 283842
- Update to new version 1.0.1

* Wed Aug 20 2008 Funda Wang <fwang@mandriva.org> 1:1.0.0-1mdv2009.0
+ Revision: 274115
- switch tarballs
--This line, aind those below, will be ignored--
  AM   SOURCES/scons-1.0.0.tar.gz
  D    SOURCES/scons-src-1.0.0.tar.gz
  M    SPECS/scons.spec
- New version 1.0.0
- rediff patch1

* Sun Aug 10 2008 Funda Wang <fwang@mandriva.org> 1:0.98.5-4mdv2009.0
+ Revision: 270527
- fix typo

* Sun Aug 10 2008 Funda Wang <fwang@mandriva.org> 1:0.98.5-3mdv2009.0
+ Revision: 270347
- add kde3 macros

* Mon Jun 16 2008 Funda Wang <fwang@mandriva.org> 1:0.98.5-2mdv2009.0
+ Revision: 219913
- Add scons macros to ease scons-based packaging

* Mon Jun 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:0.98.5-1mdv2009.0
+ Revision: 219706
- update to new version 0.98.5
- make use of %%optflags

* Sat May 03 2008 Funda Wang <fwang@mandriva.org> 1:0.98.3-1mdv2009.0
+ Revision: 200581
- New version 0.98.3

* Wed Apr 23 2008 Funda Wang <fwang@mandriva.org> 1:0.98.2-1mdv2009.0
+ Revision: 196707
- New version 0.98.2

* Wed Mar 05 2008 Oden Eriksson <oeriksson@mandriva.com> 1:0.97-2mdv2008.1
+ Revision: 179498
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue May 29 2007 David Walluck <walluck@mandriva.org> 1:0.97-1mdv2008.0
+ Revision: 32688
- use %%py_requires -d for config/Makefile needed by setup.py install
- install scons to the standard python lib location
- create two packages python-scons (the library) and scons (binaries, manpages, docs)
- 0.97
- add qt patch from Debian
- symlink scons scripts (don't install 2 copies)
- install manpages to the correct directory (%%{_mandir} not %%{_datadir})
- replace uses of  with %%{buildroot}
- explicit %%doc list


* Thu Nov 16 2006 Götz Waschk <waschk@mandriva.org> 0.96.93-1mdv2007.0
+ Revision: 85024
- Import scons

* Thu Nov 16 2006 Götz Waschk <waschk@mandriva.org> 1:0.96.93-1mdv2007.1
- New version 0.96.93

* Tue May 09 2006 Götz Waschk <waschk@mandriva.org> 0.96.92-1mdk
- drop patch
- New release 0.96.92

* Thu May 04 2006 Michael Scherer <misc@mandriva.org> 0.96.91-2mdk
- fix QT detection on i586, as found by Götz ( spurious quote in patch 0 )

* Mon Mar 06 2006 Götz Waschk <waschk@mandriva.org> 0.96.91-1mdk
- New release 0.96.91
- use mkrel

* Sun Nov 06 2005 Götz Waschk <waschk@mandriva.org> 1:0.96.1-4mdk
- make the previous fix work

* Sun Nov 06 2005 Götz Waschk <waschk@mandriva.org> 0.96.1-3mdk
- another atempt of a fix by the same Gaetan Lehmann

* Sun Nov 06 2005 Götz Waschk <waschk@mandriva.org> 1:0.96.1-2mdk
- lib64 patch by Gaetan Lehmann

* Wed Aug 03 2005 Olivier Blin <oblin@mandriva.com> 1:0.96.1-1mdk
- revert to stable version 0.96.1

* Sat Apr 16 2005 Götz Waschk <waschk@linux-mandrake.com> 0.96.90-1mdk
- New release 0.96.90

* Wed Aug 25 2004 Goetz Waschk <waschk@linux-mandrake.com> 0.96.1-1mdk
- New release 0.96.1

* Thu Aug 19 2004 Götz Waschk <waschk@linux-mandrake.com> 0.96-1mdk
- source URL
- New release 0.96

* Tue Mar 09 2004 Götz Waschk <waschk@linux-mandrake.com> 0.95-1mdk
- new version

